@@ -165,10 +165,7 @@ def test_slash_d_table_1(executor):
         ["txt1", "text", " not null"],
     ]
     headers = ["Column", "Type", "Modifiers"]
-    status = (
-        'Indexes:\n    "id_text" PRIMARY KEY, btree (id1, txt1)\n'
-        "Number of child tables: 2 (Use \\d+ to list them.)\n"
-    )
+    status = 'Indexes:\n    "id_text" PRIMARY KEY, btree (id1, txt1)\nNumber of child tables: 2 (Use \\d+ to list them.)\n'
     expected = [title, rows, headers, status]
     assert results == expected
 
@@ -211,12 +208,7 @@ def test_slash_d_table_verbose_1(executor):
         ["id1", "integer", " not null", "plain", None, None],
         ["txt1", "text", " not null", "extended", None, None],
     ]
-    status = (
-        'Indexes:\n    "id_text" PRIMARY KEY, btree (id1, txt1)\n'
-        'Child tables: "Inh1",\n'
-        "              inh2\n"
-        "Has OIDs: no\n"
-    )
+    status = 'Indexes:\n    "id_text" PRIMARY KEY, btree (id1, txt1)\nChild tables: "Inh1",\n              inh2\nHas OIDs: no\n'
     expected = [title, rows, headers, status]
     assert results == expected
 
@@ -226,7 +218,7 @@ def test_slash_d_table_verbose_1(executor):
         ["txt1", "text", " not null", "extended", None, None],
         ["value1", "integer", "", "plain", None, None],
     ]
-    status = "Inherits: tbl1\n" "Has OIDs: no\n"
+    status = "Inherits: tbl1\nHas OIDs: no\n"
     expected = [title, rows, headers, status]
     assert results == expected
 
@@ -248,7 +240,7 @@ def test_slash_d_table_verbose_2(executor):
         ],
         ["txt2", "text", "", "extended", None, None],
     ]
-    status = "Child tables: inh2\n" "Has OIDs: no\n"
+    status = "Child tables: inh2\nHas OIDs: no\n"
     expected = [title, rows, headers, status]
     assert results == expected
 
@@ -267,7 +259,7 @@ def test_slash_d_table_verbose_2(executor):
         ["txt2", "text", "", "extended", None, None],
         ["value2", "integer", "", "plain", None, None],
     ]
-    status = "Inherits: tbl1,\n" "          tbl2\n" "Has OIDs: no\n"
+    status = "Inherits: tbl1,\n          tbl2\nHas OIDs: no\n"
     expected = [title, rows, headers, status]
     assert results == expected
 
@@ -719,12 +711,12 @@ def test_slash_dF(executor):
     assert header == ["Schema", "Name", "Description"]
     assert ("pg_catalog", "spanish", "configuration for spanish language") in rows
 
-    results = executor(r"\dD *ian")
+    _ = executor(r"\dD *ian")
     assert title is None
     assert header == ["Schema", "Name", "Description"]
     assert ("pg_catalog", "russian", "configuration for russian language") in rows
 
-    results = executor(r"\dD ge*")
+    _ = executor(r"\dD ge*")
     assert title is None
     assert header == ["Schema", "Name", "Description"]
     assert ("pg_catalog", "german", "configuration for german language") in rows
@@ -982,9 +974,7 @@ def test_slash_h_alias(executor):
 @dbtest
 def test_slash_copy_to_tsv(executor, tmpdir):
     filepath = tmpdir.join("pycons.tsv")
-    executor(
-        r"\copy (SELECT 'Montréal', 'Portland', 'Cleveland') TO '{0}' ".format(filepath)
-    )
+    executor(r"\copy (SELECT 'Montréal', 'Portland', 'Cleveland') TO '{0}' ".format(filepath))
     infile = filepath.open(encoding="utf-8")
     contents = infile.read()
     assert len(contents.splitlines()) == 1
@@ -995,10 +985,7 @@ def test_slash_copy_to_tsv(executor, tmpdir):
 def test_slash_copy_throws_error_without_TO_or_FROM(executor):
     with pytest.raises(Exception) as exc_info:
         executor("\copy (SELECT 'Montréal', 'Portland', 'Cleveland') INTO stdout ")
-    assert (
-        str(exc_info.value)
-        == "Missing keyword in \\copy command. Either TO or FROM is required."
-    )
+    assert str(exc_info.value) == "Missing keyword in \\copy command. Either TO or FROM is required."
 
 
 @dbtest
@@ -1011,11 +998,7 @@ def test_slash_copy_to_stdout(executor, capsys):
 @dbtest
 def test_slash_copy_to_csv(executor, tmpdir):
     filepath = tmpdir.join("pycons.tsv")
-    executor(
-        r"\copy (SELECT 'Montréal', 'Portland', 'Cleveland') TO '{0}' WITH csv".format(
-            filepath
-        )
-    )
+    executor(r"\copy (SELECT 'Montréal', 'Portland', 'Cleveland') TO '{0}' WITH csv".format(filepath))
     infile = filepath.open(encoding="utf-8")
     contents = infile.read()
     assert len(contents.splitlines()) == 1
@@ -1037,9 +1020,7 @@ def test_slash_copy_from_csv(executor, connection, tmpdir):
 @dbtest
 def test_slash_copy_case_insensitive(executor, tmpdir):
     filepath = tmpdir.join("pycons.tsv")
-    executor(
-        r"\COPY (SELECT 'Montréal', 'Portland', 'Cleveland') TO '{0}' ".format(filepath)
-    )
+    executor(r"\COPY (SELECT 'Montréal', 'Portland', 'Cleveland') TO '{0}' ".format(filepath))
     infile = filepath.open(encoding="utf-8")
     contents = infile.read()
     assert len(contents.splitlines()) == 1
@@ -1051,12 +1032,7 @@ def test_slash_sf(executor):
     results = executor(r"\sf func1")
     title = None
     rows = [
-        (
-            "CREATE OR REPLACE FUNCTION public.func1()\n"
-            " RETURNS integer\n"
-            " LANGUAGE sql\n"
-            "AS $function$select 1$function$\n",
-        ),
+        ("CREATE OR REPLACE FUNCTION public.func1()\n RETURNS integer\n LANGUAGE sql\nAS $function$select 1$function$\n",),
     ]
     headers = ["Source"]
     status = None
@@ -1079,12 +1055,7 @@ def test_slash_sf_parens(executor):
     results = executor(r"\sf func1()")
     title = None
     rows = [
-        (
-            "CREATE OR REPLACE FUNCTION public.func1()\n"
-            " RETURNS integer\n"
-            " LANGUAGE sql\n"
-            "AS $function$select 1$function$\n",
-        ),
+        ("CREATE OR REPLACE FUNCTION public.func1()\n RETURNS integer\n LANGUAGE sql\nAS $function$select 1$function$\n",),
     ]
     headers = ["Source"]
     status = None
